Class: DocuSign_eSign::AccountUISettings
- Inherits:
-
Object
- Object
- DocuSign_eSign::AccountUISettings
- Defined in:
- lib/docusign_esign/models/account_ui_settings.rb
Overview
An object that defines the options that are available to non-administrators in the UI.
Instance Attribute Summary collapse
-
#admin_message ⇒ Object
Returns the value of attribute admin_message.
-
#ask_an_admin ⇒ Object
Returns the value of attribute ask_an_admin.
-
#clickwrap_schema_version ⇒ Object
Returns the value of attribute clickwrap_schema_version.
-
#clickwrap_schema_version_metadata ⇒ Object
Returns the value of attribute clickwrap_schema_version_metadata.
-
#enable_admin_message ⇒ Object
Returns the value of attribute enable_admin_message.
-
#enable_admin_message_metadata ⇒ Object
Returns the value of attribute enable_admin_message_metadata.
-
#enable_easy_sign_can_use_multi_template_apply ⇒ Object
Returns the value of attribute enable_easy_sign_can_use_multi_template_apply.
-
#enable_easy_sign_can_use_multi_template_apply_metadata ⇒ Object
Returns the value of attribute enable_easy_sign_can_use_multi_template_apply_metadata.
-
#enable_easy_sign_template_upload ⇒ Object
Returns the value of attribute enable_easy_sign_template_upload.
-
#enable_easy_sign_template_upload_metadata ⇒ Object
Returns the value of attribute enable_easy_sign_template_upload_metadata.
-
#enable_envelope_copy_with_data ⇒ Object
Returns the value of attribute enable_envelope_copy_with_data.
-
#enable_envelope_copy_with_data_metadata ⇒ Object
Returns the value of attribute enable_envelope_copy_with_data_metadata.
-
#enable_legacy_sendflow_link ⇒ Object
Returns the value of attribute enable_legacy_sendflow_link.
-
#enable_legacy_sendflow_link_metadata ⇒ Object
Returns the value of attribute enable_legacy_sendflow_link_metadata.
-
#has_external_linked_accounts ⇒ Object
Returns the value of attribute has_external_linked_accounts.
-
#has_external_linked_accounts_metadata ⇒ Object
Returns the value of attribute has_external_linked_accounts_metadata.
-
#hide_send_an_envelope ⇒ Object
Returns the value of attribute hide_send_an_envelope.
-
#hide_send_an_envelope_metadata ⇒ Object
Returns the value of attribute hide_send_an_envelope_metadata.
-
#hide_use_a_template ⇒ Object
Returns the value of attribute hide_use_a_template.
-
#hide_use_a_template_in_prepare ⇒ Object
Returns the value of attribute hide_use_a_template_in_prepare.
-
#hide_use_a_template_in_prepare_metadata ⇒ Object
Returns the value of attribute hide_use_a_template_in_prepare_metadata.
-
#hide_use_a_template_metadata ⇒ Object
Returns the value of attribute hide_use_a_template_metadata.
-
#order_based_recipient_id_generation ⇒ Object
Returns the value of attribute order_based_recipient_id_generation.
-
#order_based_recipient_id_generation_metadata ⇒ Object
Returns the value of attribute order_based_recipient_id_generation_metadata.
-
#remove_envelope_forwarding ⇒ Object
Returns the value of attribute remove_envelope_forwarding.
-
#remove_envelope_forwarding_metadata ⇒ Object
Returns the value of attribute remove_envelope_forwarding_metadata.
-
#should_redact_access_code ⇒ Object
Returns the value of attribute should_redact_access_code.
-
#should_redact_access_code_metadata ⇒ Object
Returns the value of attribute should_redact_access_code_metadata.
-
#upload_new_image_to_sign_or_initial ⇒ Object
Returns the value of attribute upload_new_image_to_sign_or_initial.
-
#upload_new_image_to_sign_or_initial_metadata ⇒ Object
Returns the value of attribute upload_new_image_to_sign_or_initial_metadata.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountUISettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountUISettings
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 181 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'adminMessage') self. = attributes[:'adminMessage'] end if attributes.has_key?(:'askAnAdmin') self.ask_an_admin = attributes[:'askAnAdmin'] end if attributes.has_key?(:'clickwrapSchemaVersion') self.clickwrap_schema_version = attributes[:'clickwrapSchemaVersion'] end if attributes.has_key?(:'clickwrapSchemaVersionMetadata') self. = attributes[:'clickwrapSchemaVersionMetadata'] end if attributes.has_key?(:'enableAdminMessage') self. = attributes[:'enableAdminMessage'] end if attributes.has_key?(:'enableAdminMessageMetadata') self. = attributes[:'enableAdminMessageMetadata'] end if attributes.has_key?(:'enableEasySignCanUseMultiTemplateApply') self.enable_easy_sign_can_use_multi_template_apply = attributes[:'enableEasySignCanUseMultiTemplateApply'] end if attributes.has_key?(:'enableEasySignCanUseMultiTemplateApplyMetadata') self. = attributes[:'enableEasySignCanUseMultiTemplateApplyMetadata'] end if attributes.has_key?(:'enableEasySignTemplateUpload') self.enable_easy_sign_template_upload = attributes[:'enableEasySignTemplateUpload'] end if attributes.has_key?(:'enableEasySignTemplateUploadMetadata') self. = attributes[:'enableEasySignTemplateUploadMetadata'] end if attributes.has_key?(:'enableEnvelopeCopyWithData') self.enable_envelope_copy_with_data = attributes[:'enableEnvelopeCopyWithData'] end if attributes.has_key?(:'enableEnvelopeCopyWithDataMetadata') self. = attributes[:'enableEnvelopeCopyWithDataMetadata'] end if attributes.has_key?(:'enableLegacySendflowLink') self.enable_legacy_sendflow_link = attributes[:'enableLegacySendflowLink'] end if attributes.has_key?(:'enableLegacySendflowLinkMetadata') self. = attributes[:'enableLegacySendflowLinkMetadata'] end if attributes.has_key?(:'hasExternalLinkedAccounts') self.has_external_linked_accounts = attributes[:'hasExternalLinkedAccounts'] end if attributes.has_key?(:'hasExternalLinkedAccountsMetadata') self. = attributes[:'hasExternalLinkedAccountsMetadata'] end if attributes.has_key?(:'hideSendAnEnvelope') self.hide_send_an_envelope = attributes[:'hideSendAnEnvelope'] end if attributes.has_key?(:'hideSendAnEnvelopeMetadata') self. = attributes[:'hideSendAnEnvelopeMetadata'] end if attributes.has_key?(:'hideUseATemplate') self.hide_use_a_template = attributes[:'hideUseATemplate'] end if attributes.has_key?(:'hideUseATemplateInPrepare') self.hide_use_a_template_in_prepare = attributes[:'hideUseATemplateInPrepare'] end if attributes.has_key?(:'hideUseATemplateInPrepareMetadata') self. = attributes[:'hideUseATemplateInPrepareMetadata'] end if attributes.has_key?(:'hideUseATemplateMetadata') self. = attributes[:'hideUseATemplateMetadata'] end if attributes.has_key?(:'orderBasedRecipientIdGeneration') self.order_based_recipient_id_generation = attributes[:'orderBasedRecipientIdGeneration'] end if attributes.has_key?(:'orderBasedRecipientIdGenerationMetadata') self. = attributes[:'orderBasedRecipientIdGenerationMetadata'] end if attributes.has_key?(:'removeEnvelopeForwarding') self.remove_envelope_forwarding = attributes[:'removeEnvelopeForwarding'] end if attributes.has_key?(:'removeEnvelopeForwardingMetadata') self. = attributes[:'removeEnvelopeForwardingMetadata'] end if attributes.has_key?(:'shouldRedactAccessCode') self.should_redact_access_code = attributes[:'shouldRedactAccessCode'] end if attributes.has_key?(:'shouldRedactAccessCodeMetadata') self. = attributes[:'shouldRedactAccessCodeMetadata'] end if attributes.has_key?(:'uploadNewImageToSignOrInitial') self.upload_new_image_to_sign_or_initial = attributes[:'uploadNewImageToSignOrInitial'] end if attributes.has_key?(:'uploadNewImageToSignOrInitialMetadata') self. = attributes[:'uploadNewImageToSignOrInitialMetadata'] end end |
Instance Attribute Details
#admin_message ⇒ Object
Returns the value of attribute admin_message.
18 19 20 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 18 def @admin_message end |
#ask_an_admin ⇒ Object
Returns the value of attribute ask_an_admin.
21 22 23 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 21 def ask_an_admin @ask_an_admin end |
#clickwrap_schema_version ⇒ Object
Returns the value of attribute clickwrap_schema_version.
24 25 26 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 24 def clickwrap_schema_version @clickwrap_schema_version end |
#clickwrap_schema_version_metadata ⇒ Object
Returns the value of attribute clickwrap_schema_version_metadata.
27 28 29 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 27 def @clickwrap_schema_version_metadata end |
#enable_admin_message ⇒ Object
Returns the value of attribute enable_admin_message.
30 31 32 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 30 def @enable_admin_message end |
#enable_admin_message_metadata ⇒ Object
Returns the value of attribute enable_admin_message_metadata.
33 34 35 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 33 def @enable_admin_message_metadata end |
#enable_easy_sign_can_use_multi_template_apply ⇒ Object
Returns the value of attribute enable_easy_sign_can_use_multi_template_apply.
36 37 38 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 36 def enable_easy_sign_can_use_multi_template_apply @enable_easy_sign_can_use_multi_template_apply end |
#enable_easy_sign_can_use_multi_template_apply_metadata ⇒ Object
Returns the value of attribute enable_easy_sign_can_use_multi_template_apply_metadata.
39 40 41 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 39 def @enable_easy_sign_can_use_multi_template_apply_metadata end |
#enable_easy_sign_template_upload ⇒ Object
Returns the value of attribute enable_easy_sign_template_upload.
42 43 44 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 42 def enable_easy_sign_template_upload @enable_easy_sign_template_upload end |
#enable_easy_sign_template_upload_metadata ⇒ Object
Returns the value of attribute enable_easy_sign_template_upload_metadata.
45 46 47 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 45 def @enable_easy_sign_template_upload_metadata end |
#enable_envelope_copy_with_data ⇒ Object
Returns the value of attribute enable_envelope_copy_with_data.
48 49 50 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 48 def enable_envelope_copy_with_data @enable_envelope_copy_with_data end |
#enable_envelope_copy_with_data_metadata ⇒ Object
Returns the value of attribute enable_envelope_copy_with_data_metadata.
51 52 53 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 51 def @enable_envelope_copy_with_data_metadata end |
#enable_legacy_sendflow_link ⇒ Object
Returns the value of attribute enable_legacy_sendflow_link.
54 55 56 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 54 def enable_legacy_sendflow_link @enable_legacy_sendflow_link end |
#enable_legacy_sendflow_link_metadata ⇒ Object
Returns the value of attribute enable_legacy_sendflow_link_metadata.
57 58 59 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 57 def @enable_legacy_sendflow_link_metadata end |
#has_external_linked_accounts ⇒ Object
Returns the value of attribute has_external_linked_accounts.
60 61 62 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 60 def has_external_linked_accounts @has_external_linked_accounts end |
#has_external_linked_accounts_metadata ⇒ Object
Returns the value of attribute has_external_linked_accounts_metadata.
63 64 65 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 63 def @has_external_linked_accounts_metadata end |
#hide_send_an_envelope ⇒ Object
Returns the value of attribute hide_send_an_envelope.
66 67 68 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 66 def hide_send_an_envelope @hide_send_an_envelope end |
#hide_send_an_envelope_metadata ⇒ Object
Returns the value of attribute hide_send_an_envelope_metadata.
69 70 71 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 69 def @hide_send_an_envelope_metadata end |
#hide_use_a_template ⇒ Object
Returns the value of attribute hide_use_a_template.
72 73 74 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 72 def hide_use_a_template @hide_use_a_template end |
#hide_use_a_template_in_prepare ⇒ Object
Returns the value of attribute hide_use_a_template_in_prepare.
75 76 77 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 75 def hide_use_a_template_in_prepare @hide_use_a_template_in_prepare end |
#hide_use_a_template_in_prepare_metadata ⇒ Object
Returns the value of attribute hide_use_a_template_in_prepare_metadata.
78 79 80 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 78 def @hide_use_a_template_in_prepare_metadata end |
#hide_use_a_template_metadata ⇒ Object
Returns the value of attribute hide_use_a_template_metadata.
81 82 83 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 81 def @hide_use_a_template_metadata end |
#order_based_recipient_id_generation ⇒ Object
Returns the value of attribute order_based_recipient_id_generation.
84 85 86 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 84 def order_based_recipient_id_generation @order_based_recipient_id_generation end |
#order_based_recipient_id_generation_metadata ⇒ Object
Returns the value of attribute order_based_recipient_id_generation_metadata.
87 88 89 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 87 def @order_based_recipient_id_generation_metadata end |
#remove_envelope_forwarding ⇒ Object
Returns the value of attribute remove_envelope_forwarding.
90 91 92 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 90 def remove_envelope_forwarding @remove_envelope_forwarding end |
#remove_envelope_forwarding_metadata ⇒ Object
Returns the value of attribute remove_envelope_forwarding_metadata.
93 94 95 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 93 def @remove_envelope_forwarding_metadata end |
#should_redact_access_code ⇒ Object
Returns the value of attribute should_redact_access_code.
96 97 98 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 96 def should_redact_access_code @should_redact_access_code end |
#should_redact_access_code_metadata ⇒ Object
Returns the value of attribute should_redact_access_code_metadata.
99 100 101 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 99 def @should_redact_access_code_metadata end |
#upload_new_image_to_sign_or_initial ⇒ Object
Returns the value of attribute upload_new_image_to_sign_or_initial.
102 103 104 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 102 def upload_new_image_to_sign_or_initial @upload_new_image_to_sign_or_initial end |
#upload_new_image_to_sign_or_initial_metadata ⇒ Object
Returns the value of attribute upload_new_image_to_sign_or_initial_metadata.
105 106 107 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 105 def @upload_new_image_to_sign_or_initial_metadata end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 108 def self.attribute_map { :'admin_message' => :'adminMessage', :'ask_an_admin' => :'askAnAdmin', :'clickwrap_schema_version' => :'clickwrapSchemaVersion', :'clickwrap_schema_version_metadata' => :'clickwrapSchemaVersionMetadata', :'enable_admin_message' => :'enableAdminMessage', :'enable_admin_message_metadata' => :'enableAdminMessageMetadata', :'enable_easy_sign_can_use_multi_template_apply' => :'enableEasySignCanUseMultiTemplateApply', :'enable_easy_sign_can_use_multi_template_apply_metadata' => :'enableEasySignCanUseMultiTemplateApplyMetadata', :'enable_easy_sign_template_upload' => :'enableEasySignTemplateUpload', :'enable_easy_sign_template_upload_metadata' => :'enableEasySignTemplateUploadMetadata', :'enable_envelope_copy_with_data' => :'enableEnvelopeCopyWithData', :'enable_envelope_copy_with_data_metadata' => :'enableEnvelopeCopyWithDataMetadata', :'enable_legacy_sendflow_link' => :'enableLegacySendflowLink', :'enable_legacy_sendflow_link_metadata' => :'enableLegacySendflowLinkMetadata', :'has_external_linked_accounts' => :'hasExternalLinkedAccounts', :'has_external_linked_accounts_metadata' => :'hasExternalLinkedAccountsMetadata', :'hide_send_an_envelope' => :'hideSendAnEnvelope', :'hide_send_an_envelope_metadata' => :'hideSendAnEnvelopeMetadata', :'hide_use_a_template' => :'hideUseATemplate', :'hide_use_a_template_in_prepare' => :'hideUseATemplateInPrepare', :'hide_use_a_template_in_prepare_metadata' => :'hideUseATemplateInPrepareMetadata', :'hide_use_a_template_metadata' => :'hideUseATemplateMetadata', :'order_based_recipient_id_generation' => :'orderBasedRecipientIdGeneration', :'order_based_recipient_id_generation_metadata' => :'orderBasedRecipientIdGenerationMetadata', :'remove_envelope_forwarding' => :'removeEnvelopeForwarding', :'remove_envelope_forwarding_metadata' => :'removeEnvelopeForwardingMetadata', :'should_redact_access_code' => :'shouldRedactAccessCode', :'should_redact_access_code_metadata' => :'shouldRedactAccessCodeMetadata', :'upload_new_image_to_sign_or_initial' => :'uploadNewImageToSignOrInitial', :'upload_new_image_to_sign_or_initial_metadata' => :'uploadNewImageToSignOrInitialMetadata' } end |
.swagger_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 144 def self.swagger_types { :'admin_message' => :'AdminMessage', :'ask_an_admin' => :'AskAnAdmin', :'clickwrap_schema_version' => :'String', :'clickwrap_schema_version_metadata' => :'SettingsMetadata', :'enable_admin_message' => :'String', :'enable_admin_message_metadata' => :'SettingsMetadata', :'enable_easy_sign_can_use_multi_template_apply' => :'String', :'enable_easy_sign_can_use_multi_template_apply_metadata' => :'SettingsMetadata', :'enable_easy_sign_template_upload' => :'String', :'enable_easy_sign_template_upload_metadata' => :'SettingsMetadata', :'enable_envelope_copy_with_data' => :'String', :'enable_envelope_copy_with_data_metadata' => :'SettingsMetadata', :'enable_legacy_sendflow_link' => :'String', :'enable_legacy_sendflow_link_metadata' => :'SettingsMetadata', :'has_external_linked_accounts' => :'String', :'has_external_linked_accounts_metadata' => :'SettingsMetadata', :'hide_send_an_envelope' => :'String', :'hide_send_an_envelope_metadata' => :'SettingsMetadata', :'hide_use_a_template' => :'String', :'hide_use_a_template_in_prepare' => :'String', :'hide_use_a_template_in_prepare_metadata' => :'SettingsMetadata', :'hide_use_a_template_metadata' => :'SettingsMetadata', :'order_based_recipient_id_generation' => :'String', :'order_based_recipient_id_generation_metadata' => :'SettingsMetadata', :'remove_envelope_forwarding' => :'String', :'remove_envelope_forwarding_metadata' => :'SettingsMetadata', :'should_redact_access_code' => :'String', :'should_redact_access_code_metadata' => :'SettingsMetadata', :'upload_new_image_to_sign_or_initial' => :'String', :'upload_new_image_to_sign_or_initial_metadata' => :'SettingsMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 323 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && ask_an_admin == o.ask_an_admin && clickwrap_schema_version == o.clickwrap_schema_version && == o. && == o. && == o. && enable_easy_sign_can_use_multi_template_apply == o.enable_easy_sign_can_use_multi_template_apply && == o. && enable_easy_sign_template_upload == o.enable_easy_sign_template_upload && == o. && enable_envelope_copy_with_data == o.enable_envelope_copy_with_data && == o. && enable_legacy_sendflow_link == o.enable_legacy_sendflow_link && == o. && has_external_linked_accounts == o.has_external_linked_accounts && == o. && hide_send_an_envelope == o.hide_send_an_envelope && == o. && hide_use_a_template == o.hide_use_a_template && hide_use_a_template_in_prepare == o.hide_use_a_template_in_prepare && == o. && == o. && order_based_recipient_id_generation == o.order_based_recipient_id_generation && == o. && remove_envelope_forwarding == o.remove_envelope_forwarding && == o. && should_redact_access_code == o.should_redact_access_code && == o. && upload_new_image_to_sign_or_initial == o.upload_new_image_to_sign_or_initial && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 394 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_eSign.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 460 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 373 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
360 361 362 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 360 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 366 def hash [, ask_an_admin, clickwrap_schema_version, , , , enable_easy_sign_can_use_multi_template_apply, , enable_easy_sign_template_upload, , enable_envelope_copy_with_data, , enable_legacy_sendflow_link, , has_external_linked_accounts, , hide_send_an_envelope, , hide_use_a_template, hide_use_a_template_in_prepare, , , order_based_recipient_id_generation, , remove_envelope_forwarding, , should_redact_access_code, , upload_new_image_to_sign_or_initial, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
310 311 312 313 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 310 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
440 441 442 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 440 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
446 447 448 449 450 451 452 453 454 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 446 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
434 435 436 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 434 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
317 318 319 |
# File 'lib/docusign_esign/models/account_ui_settings.rb', line 317 def valid? true end |