Class: DocuSign_eSign::Contact

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_esign/models/contact.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Contact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/docusign_esign/models/contact.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'canManage')
    self.can_manage = attributes[:'canManage']
  end

  if attributes.has_key?(:'cloudProvider')
    self.cloud_provider = attributes[:'cloudProvider']
  end

  if attributes.has_key?(:'cloudProviderContainerId')
    self.cloud_provider_container_id = attributes[:'cloudProviderContainerId']
  end

  if attributes.has_key?(:'contactId')
    self.contact_id = attributes[:'contactId']
  end

  if attributes.has_key?(:'contactPhoneNumbers')
    if (value = attributes[:'contactPhoneNumbers']).is_a?(Array)
      self.contact_phone_numbers = value
    end
  end

  if attributes.has_key?(:'contactUri')
    self.contact_uri = attributes[:'contactUri']
  end

  if attributes.has_key?(:'emails')
    if (value = attributes[:'emails']).is_a?(Array)
      self.emails = value
    end
  end

  if attributes.has_key?(:'errorDetails')
    self.error_details = attributes[:'errorDetails']
  end

  if attributes.has_key?(:'isOwner')
    self.is_owner = attributes[:'isOwner']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'notaryContactDetails')
    self.notary_contact_details = attributes[:'notaryContactDetails']
  end

  if attributes.has_key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.has_key?(:'roomContactType')
    self.room_contact_type = attributes[:'roomContactType']
  end

  if attributes.has_key?(:'shared')
    self.shared = attributes[:'shared']
  end

  if attributes.has_key?(:'signingGroup')
    self.signing_group = attributes[:'signingGroup']
  end

  if attributes.has_key?(:'signingGroupName')
    self.signing_group_name = attributes[:'signingGroupName']
  end
end

Instance Attribute Details

#can_manageObject

Returns the value of attribute can_manage.



17
18
19
# File 'lib/docusign_esign/models/contact.rb', line 17

def can_manage
  @can_manage
end

#cloud_providerObject

Returns the value of attribute cloud_provider.



20
21
22
# File 'lib/docusign_esign/models/contact.rb', line 20

def cloud_provider
  @cloud_provider
end

#cloud_provider_container_idObject

Returns the value of attribute cloud_provider_container_id.



23
24
25
# File 'lib/docusign_esign/models/contact.rb', line 23

def cloud_provider_container_id
  @cloud_provider_container_id
end

#contact_idObject

Returns the value of attribute contact_id.



26
27
28
# File 'lib/docusign_esign/models/contact.rb', line 26

def contact_id
  @contact_id
end

#contact_phone_numbersObject

Returns the value of attribute contact_phone_numbers.



29
30
31
# File 'lib/docusign_esign/models/contact.rb', line 29

def contact_phone_numbers
  @contact_phone_numbers
end

#contact_uriObject

Returns the value of attribute contact_uri.



32
33
34
# File 'lib/docusign_esign/models/contact.rb', line 32

def contact_uri
  @contact_uri
end

#emailsObject

Returns the value of attribute emails.



35
36
37
# File 'lib/docusign_esign/models/contact.rb', line 35

def emails
  @emails
end

#error_detailsObject

Array or errors.



38
39
40
# File 'lib/docusign_esign/models/contact.rb', line 38

def error_details
  @error_details
end

#is_ownerObject

Returns the value of attribute is_owner.



41
42
43
# File 'lib/docusign_esign/models/contact.rb', line 41

def is_owner
  @is_owner
end

#nameObject

Returns the value of attribute name.



44
45
46
# File 'lib/docusign_esign/models/contact.rb', line 44

def name
  @name
end

#notary_contact_detailsObject

Returns the value of attribute notary_contact_details.



47
48
49
# File 'lib/docusign_esign/models/contact.rb', line 47

def notary_contact_details
  @notary_contact_details
end

#organizationObject

Returns the value of attribute organization.



50
51
52
# File 'lib/docusign_esign/models/contact.rb', line 50

def organization
  @organization
end

#room_contact_typeObject

Returns the value of attribute room_contact_type.



53
54
55
# File 'lib/docusign_esign/models/contact.rb', line 53

def room_contact_type
  @room_contact_type
end

#sharedObject

When set to true, this custom tab is shared.



56
57
58
# File 'lib/docusign_esign/models/contact.rb', line 56

def shared
  @shared
end

#signing_groupObject

Returns the value of attribute signing_group.



59
60
61
# File 'lib/docusign_esign/models/contact.rb', line 59

def signing_group
  @signing_group
end

#signing_group_nameObject

The display name for the signing group. Maximum Length: 100 characters.



62
63
64
# File 'lib/docusign_esign/models/contact.rb', line 62

def signing_group_name
  @signing_group_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/docusign_esign/models/contact.rb', line 65

def self.attribute_map
  {
    :'can_manage' => :'canManage',
    :'cloud_provider' => :'cloudProvider',
    :'cloud_provider_container_id' => :'cloudProviderContainerId',
    :'contact_id' => :'contactId',
    :'contact_phone_numbers' => :'contactPhoneNumbers',
    :'contact_uri' => :'contactUri',
    :'emails' => :'emails',
    :'error_details' => :'errorDetails',
    :'is_owner' => :'isOwner',
    :'name' => :'name',
    :'notary_contact_details' => :'notaryContactDetails',
    :'organization' => :'organization',
    :'room_contact_type' => :'roomContactType',
    :'shared' => :'shared',
    :'signing_group' => :'signingGroup',
    :'signing_group_name' => :'signingGroupName'
  }
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/docusign_esign/models/contact.rb', line 87

def self.swagger_types
  {
    :'can_manage' => :'String',
    :'cloud_provider' => :'String',
    :'cloud_provider_container_id' => :'String',
    :'contact_id' => :'String',
    :'contact_phone_numbers' => :'Array<ContactPhoneNumber>',
    :'contact_uri' => :'String',
    :'emails' => :'Array<String>',
    :'error_details' => :'ErrorDetails',
    :'is_owner' => :'BOOLEAN',
    :'name' => :'String',
    :'notary_contact_details' => :'NotaryContactDetails',
    :'organization' => :'String',
    :'room_contact_type' => :'String',
    :'shared' => :'String',
    :'signing_group' => :'String',
    :'signing_group_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/docusign_esign/models/contact.rb', line 200

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      can_manage == o.can_manage &&
      cloud_provider == o.cloud_provider &&
      cloud_provider_container_id == o.cloud_provider_container_id &&
      contact_id == o.contact_id &&
      contact_phone_numbers == o.contact_phone_numbers &&
      contact_uri == o.contact_uri &&
      emails == o.emails &&
      error_details == o.error_details &&
      is_owner == o.is_owner &&
      name == o.name &&
      notary_contact_details == o.notary_contact_details &&
      organization == o.organization &&
      room_contact_type == o.room_contact_type &&
      shared == o.shared &&
      signing_group == o.signing_group &&
      signing_group_name == o.signing_group_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/docusign_esign/models/contact.rb', line 257

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_eSign.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/docusign_esign/models/contact.rb', line 323

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/docusign_esign/models/contact.rb', line 236

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/docusign_esign/models/contact.rb', line 223

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



229
230
231
# File 'lib/docusign_esign/models/contact.rb', line 229

def hash
  [can_manage, cloud_provider, cloud_provider_container_id, contact_id, contact_phone_numbers, contact_uri, emails, error_details, is_owner, name, notary_contact_details, organization, room_contact_type, shared, signing_group, signing_group_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
# File 'lib/docusign_esign/models/contact.rb', line 187

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
# File 'lib/docusign_esign/models/contact.rb', line 303

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
# File 'lib/docusign_esign/models/contact.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



297
298
299
# File 'lib/docusign_esign/models/contact.rb', line 297

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
# File 'lib/docusign_esign/models/contact.rb', line 194

def valid?
  true
end