Class: DocuSign_eSign::CreateRecipientOptions
- Inherits:
-
Object
- Object
- DocuSign_eSign::CreateRecipientOptions
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb
Instance Attribute Summary collapse
-
#resend_envelope ⇒ Object
When set to *true*, resends the envelope if the new recipient's routing order is before or the same as the envelope's next recipient.
Class Method Summary collapse
Instance Attribute Details
#resend_envelope ⇒ Object
When set to *true*, resends the envelope if the new recipient's routing order is before or the same as the envelope's next recipient.
57 58 59 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 57 def resend_envelope @resend_envelope end |
Class Method Details
.default ⇒ Object
59 60 61 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 59 def self.default @@default ||= CreateRecipientOptions.new end |