Class: DocuSign_eSign::ListRecipientsOptions
- Inherits:
-
Object
- Object
- DocuSign_eSign::ListRecipientsOptions
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb,
lib/docusign_esign/api/templates_api.rb
Instance Attribute Summary collapse
-
#include_anchor_tab_locations ⇒ Object
When set to true and ‘include_tabs` is set to true, all tabs with anchor tab properties are included in the response.
-
#include_extended ⇒ Object
When set to true, the extended properties are included in the response.
-
#include_metadata ⇒ Object
Returns the value of attribute include_metadata.
-
#include_tabs ⇒ Object
When set to true, the tab information associated with the recipient is included in the response.
Class Method Summary collapse
Instance Attribute Details
#include_anchor_tab_locations ⇒ Object
When set to true and ‘include_tabs` is set to true, all tabs with anchor tab properties are included in the response.
324 325 326 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 324 def include_anchor_tab_locations @include_anchor_tab_locations end |
#include_extended ⇒ Object
When set to true, the extended properties are included in the response.
327 328 329 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 327 def include_extended @include_extended end |
#include_metadata ⇒ Object
Returns the value of attribute include_metadata.
330 331 332 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 330 def @include_metadata end |
#include_tabs ⇒ Object
When set to true, the tab information associated with the recipient is included in the response.
333 334 335 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 333 def include_tabs @include_tabs end |
Class Method Details
.default ⇒ Object
335 336 337 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 335 def self.default @@default ||= ListRecipientsOptions.new end |