Class: DocuSign_eSign::PaymentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_esign/models/payment_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentDetails

Initializes the object



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/docusign_esign/models/payment_details.rb', line 81

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'allowedPaymentMethods')
    if (value = attributes[:'allowedPaymentMethods']).is_a?(Array)
      self.allowed_payment_methods = value
    end
  end

  if attributes.has_key?(:'chargeId')
    self.charge_id = attributes[:'chargeId']
  end

  if attributes.has_key?(:'currencyCode')
    self.currency_code = attributes[:'currencyCode']
  end

  if attributes.has_key?(:'gatewayAccountId')
    self. = attributes[:'gatewayAccountId']
  end

  if attributes.has_key?(:'gatewayDisplayName')
    self.gateway_display_name = attributes[:'gatewayDisplayName']
  end

  if attributes.has_key?(:'gatewayName')
    self.gateway_name = attributes[:'gatewayName']
  end

  if attributes.has_key?(:'lineItems')
    if (value = attributes[:'lineItems']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.has_key?(:'paymentOption')
    self.payment_option = attributes[:'paymentOption']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'total')
    self.total = attributes[:'total']
  end

end

Instance Attribute Details

#allowed_payment_methodsObject

Returns the value of attribute allowed_payment_methods.



18
19
20
# File 'lib/docusign_esign/models/payment_details.rb', line 18

def allowed_payment_methods
  @allowed_payment_methods
end

#charge_idObject

Returns the value of attribute charge_id.



21
22
23
# File 'lib/docusign_esign/models/payment_details.rb', line 21

def charge_id
  @charge_id
end

#currency_codeObject

Returns the value of attribute currency_code.



24
25
26
# File 'lib/docusign_esign/models/payment_details.rb', line 24

def currency_code
  @currency_code
end

#gateway_account_idObject

Returns the value of attribute gateway_account_id.



27
28
29
# File 'lib/docusign_esign/models/payment_details.rb', line 27

def 
  
end

#gateway_display_nameObject

Returns the value of attribute gateway_display_name.



30
31
32
# File 'lib/docusign_esign/models/payment_details.rb', line 30

def gateway_display_name
  @gateway_display_name
end

#gateway_nameObject

Returns the value of attribute gateway_name.



33
34
35
# File 'lib/docusign_esign/models/payment_details.rb', line 33

def gateway_name
  @gateway_name
end

#line_itemsObject

Returns the value of attribute line_items.



36
37
38
# File 'lib/docusign_esign/models/payment_details.rb', line 36

def line_items
  @line_items
end

#payment_optionObject

Returns the value of attribute payment_option.



39
40
41
# File 'lib/docusign_esign/models/payment_details.rb', line 39

def payment_option
  @payment_option
end

#statusObject

Indicates the envelope status. Valid values are: * sent - The envelope is sent to the recipients. * created - The envelope is saved as a draft and can be modified and sent later.



42
43
44
# File 'lib/docusign_esign/models/payment_details.rb', line 42

def status
  @status
end

#totalObject

Returns the value of attribute total.



44
45
46
# File 'lib/docusign_esign/models/payment_details.rb', line 44

def total
  @total
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/docusign_esign/models/payment_details.rb', line 48

def self.attribute_map
  {
    :'allowed_payment_methods' => :'allowedPaymentMethods',
    :'charge_id' => :'chargeId',
    :'currency_code' => :'currencyCode',
    :'gateway_account_id' => :'gatewayAccountId',
    :'gateway_display_name' => :'gatewayDisplayName',
    :'gateway_name' => :'gatewayName',
    :'line_items' => :'lineItems',
    :'payment_option' => :'paymentOption',
    :'status' => :'status',
    :'total' => :'total'
  }
end

.swagger_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/docusign_esign/models/payment_details.rb', line 64

def self.swagger_types
  {
    :'allowed_payment_methods' => :'Array<String>',
    :'charge_id' => :'String',
    :'currency_code' => :'String',
    :'gateway_account_id' => :'String',
    :'gateway_display_name' => :'String',
    :'gateway_name' => :'String',
    :'line_items' => :'Array<PaymentLineItem>',
    :'payment_option' => :'String',
    :'status' => :'String',
    :'total' => :'Money'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/docusign_esign/models/payment_details.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allowed_payment_methods == o.allowed_payment_methods &&
      charge_id == o.charge_id &&
      currency_code == o.currency_code &&
       == o. &&
      gateway_display_name == o.gateway_display_name &&
      gateway_name == o.gateway_name &&
      line_items == o.line_items &&
      payment_option == o.payment_option &&
      status == o.status &&
      total == o.total
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/docusign_esign/models/payment_details.rb', line 199

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_eSign.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/docusign_esign/models/payment_details.rb', line 265

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/docusign_esign/models/payment_details.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


165
166
167
# File 'lib/docusign_esign/models/payment_details.rb', line 165

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



171
172
173
# File 'lib/docusign_esign/models/payment_details.rb', line 171

def hash
  [allowed_payment_methods, charge_id, currency_code, , gateway_display_name, gateway_name, line_items, payment_option, status, total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



135
136
137
138
# File 'lib/docusign_esign/models/payment_details.rb', line 135

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



245
246
247
# File 'lib/docusign_esign/models/payment_details.rb', line 245

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
# File 'lib/docusign_esign/models/payment_details.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



239
240
241
# File 'lib/docusign_esign/models/payment_details.rb', line 239

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



142
143
144
# File 'lib/docusign_esign/models/payment_details.rb', line 142

def valid?
  return true
end