Class: DocuSign_eSign::Recipients
- Inherits:
-
Object
- Object
- DocuSign_eSign::Recipients
- Defined in:
- lib/docusign_esign/models/recipients.rb
Overview
Specifies the envelope recipients.
Instance Attribute Summary collapse
-
#agents ⇒ Object
A complex type defining the management and access rights of a recipient assigned assigned as an agent on the document.
-
#authorized_signatories ⇒ Object
Returns the value of attribute authorized_signatories.
-
#carbon_copies ⇒ Object
A complex type containing information about recipients who should receive a copy of the envelope, but does not need to sign it.
-
#certified_deliveries ⇒ Object
A complex type containing information on a recipient the must receive the completed documents for the envelope to be completed, but the recipient does not need to sign, initial, date, or add information to any of the documents.
-
#current_routing_order ⇒ Object
Returns the value of attribute current_routing_order.
-
#editors ⇒ Object
A complex type defining the management and access rights of a recipient assigned assigned as an editor on the document.
-
#error_details ⇒ Object
Array or errors.
-
#in_person_signers ⇒ Object
Specifies a signer that is in the same physical location as a DocuSign user who will act as a Signing Host for the transaction.
-
#intermediaries ⇒ Object
Identifies a recipient that can, but is not required to, add name and email information for recipients at the same or subsequent level in the routing order (until subsequent Agents, Editors or Intermediaries recipient types are added).
-
#notaries ⇒ Object
Returns the value of attribute notaries.
-
#notary_witnesses ⇒ Object
Returns the value of attribute notary_witnesses.
-
#participants ⇒ Object
Returns the value of attribute participants.
-
#recipient_count ⇒ Object
Returns the value of attribute recipient_count.
-
#seals ⇒ Object
Returns the value of attribute seals.
-
#signers ⇒ Object
A complex type containing information about the Signer recipient.
-
#witnesses ⇒ Object
Returns the value of attribute witnesses.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Recipients
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Recipients
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/docusign_esign/models/recipients.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'agents') if (value = attributes[:'agents']).is_a?(Array) self.agents = value end end if attributes.has_key?(:'authorizedSignatories') if (value = attributes[:'authorizedSignatories']).is_a?(Array) self. = value end end if attributes.has_key?(:'carbonCopies') if (value = attributes[:'carbonCopies']).is_a?(Array) self.carbon_copies = value end end if attributes.has_key?(:'certifiedDeliveries') if (value = attributes[:'certifiedDeliveries']).is_a?(Array) self.certified_deliveries = value end end if attributes.has_key?(:'currentRoutingOrder') self.current_routing_order = attributes[:'currentRoutingOrder'] end if attributes.has_key?(:'editors') if (value = attributes[:'editors']).is_a?(Array) self.editors = value end end if attributes.has_key?(:'errorDetails') self.error_details = attributes[:'errorDetails'] end if attributes.has_key?(:'inPersonSigners') if (value = attributes[:'inPersonSigners']).is_a?(Array) self.in_person_signers = value end end if attributes.has_key?(:'intermediaries') if (value = attributes[:'intermediaries']).is_a?(Array) self.intermediaries = value end end if attributes.has_key?(:'notaries') if (value = attributes[:'notaries']).is_a?(Array) self.notaries = value end end if attributes.has_key?(:'notaryWitnesses') if (value = attributes[:'notaryWitnesses']).is_a?(Array) self.notary_witnesses = value end end if attributes.has_key?(:'participants') if (value = attributes[:'participants']).is_a?(Array) self.participants = value end end if attributes.has_key?(:'recipientCount') self.recipient_count = attributes[:'recipientCount'] end if attributes.has_key?(:'seals') if (value = attributes[:'seals']).is_a?(Array) self.seals = value end end if attributes.has_key?(:'signers') if (value = attributes[:'signers']).is_a?(Array) self.signers = value end end if attributes.has_key?(:'witnesses') if (value = attributes[:'witnesses']).is_a?(Array) self.witnesses = value end end end |
Instance Attribute Details
#agents ⇒ Object
A complex type defining the management and access rights of a recipient assigned assigned as an agent on the document.
18 19 20 |
# File 'lib/docusign_esign/models/recipients.rb', line 18 def agents @agents end |
#authorized_signatories ⇒ Object
Returns the value of attribute authorized_signatories.
21 22 23 |
# File 'lib/docusign_esign/models/recipients.rb', line 21 def @authorized_signatories end |
#carbon_copies ⇒ Object
A complex type containing information about recipients who should receive a copy of the envelope, but does not need to sign it.
24 25 26 |
# File 'lib/docusign_esign/models/recipients.rb', line 24 def carbon_copies @carbon_copies end |
#certified_deliveries ⇒ Object
A complex type containing information on a recipient the must receive the completed documents for the envelope to be completed, but the recipient does not need to sign, initial, date, or add information to any of the documents.
27 28 29 |
# File 'lib/docusign_esign/models/recipients.rb', line 27 def certified_deliveries @certified_deliveries end |
#current_routing_order ⇒ Object
Returns the value of attribute current_routing_order.
30 31 32 |
# File 'lib/docusign_esign/models/recipients.rb', line 30 def current_routing_order @current_routing_order end |
#editors ⇒ Object
A complex type defining the management and access rights of a recipient assigned assigned as an editor on the document.
33 34 35 |
# File 'lib/docusign_esign/models/recipients.rb', line 33 def editors @editors end |
#error_details ⇒ Object
Array or errors.
36 37 38 |
# File 'lib/docusign_esign/models/recipients.rb', line 36 def error_details @error_details end |
#in_person_signers ⇒ Object
Specifies a signer that is in the same physical location as a DocuSign user who will act as a Signing Host for the transaction. The recipient added is the Signing Host and new separate Signer Name field appears after Sign in person is selected.
39 40 41 |
# File 'lib/docusign_esign/models/recipients.rb', line 39 def in_person_signers @in_person_signers end |
#intermediaries ⇒ Object
Identifies a recipient that can, but is not required to, add name and email information for recipients at the same or subsequent level in the routing order (until subsequent Agents, Editors or Intermediaries recipient types are added).
42 43 44 |
# File 'lib/docusign_esign/models/recipients.rb', line 42 def intermediaries @intermediaries end |
#notaries ⇒ Object
Returns the value of attribute notaries.
45 46 47 |
# File 'lib/docusign_esign/models/recipients.rb', line 45 def notaries @notaries end |
#notary_witnesses ⇒ Object
Returns the value of attribute notary_witnesses.
48 49 50 |
# File 'lib/docusign_esign/models/recipients.rb', line 48 def notary_witnesses @notary_witnesses end |
#participants ⇒ Object
Returns the value of attribute participants.
51 52 53 |
# File 'lib/docusign_esign/models/recipients.rb', line 51 def participants @participants end |
#recipient_count ⇒ Object
Returns the value of attribute recipient_count.
54 55 56 |
# File 'lib/docusign_esign/models/recipients.rb', line 54 def recipient_count @recipient_count end |
#seals ⇒ Object
Returns the value of attribute seals.
57 58 59 |
# File 'lib/docusign_esign/models/recipients.rb', line 57 def seals @seals end |
#signers ⇒ Object
A complex type containing information about the Signer recipient.
60 61 62 |
# File 'lib/docusign_esign/models/recipients.rb', line 60 def signers @signers end |
#witnesses ⇒ Object
Returns the value of attribute witnesses.
63 64 65 |
# File 'lib/docusign_esign/models/recipients.rb', line 63 def witnesses @witnesses end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/docusign_esign/models/recipients.rb', line 66 def self.attribute_map { :'agents' => :'agents', :'authorized_signatories' => :'authorizedSignatories', :'carbon_copies' => :'carbonCopies', :'certified_deliveries' => :'certifiedDeliveries', :'current_routing_order' => :'currentRoutingOrder', :'editors' => :'editors', :'error_details' => :'errorDetails', :'in_person_signers' => :'inPersonSigners', :'intermediaries' => :'intermediaries', :'notaries' => :'notaries', :'notary_witnesses' => :'notaryWitnesses', :'participants' => :'participants', :'recipient_count' => :'recipientCount', :'seals' => :'seals', :'signers' => :'signers', :'witnesses' => :'witnesses' } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/docusign_esign/models/recipients.rb', line 88 def self.swagger_types { :'agents' => :'Array<Agent>', :'authorized_signatories' => :'Array<AuthorizedSignatory>', :'carbon_copies' => :'Array<CarbonCopy>', :'certified_deliveries' => :'Array<CertifiedDelivery>', :'current_routing_order' => :'String', :'editors' => :'Array<Editor>', :'error_details' => :'ErrorDetails', :'in_person_signers' => :'Array<InPersonSigner>', :'intermediaries' => :'Array<Intermediary>', :'notaries' => :'Array<NotaryRecipient>', :'notary_witnesses' => :'Array<NotaryWitness>', :'participants' => :'Array<Participant>', :'recipient_count' => :'String', :'seals' => :'Array<SealSign>', :'signers' => :'Array<Signer>', :'witnesses' => :'Array<Witness>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/docusign_esign/models/recipients.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && agents == o.agents && == o. && carbon_copies == o.carbon_copies && certified_deliveries == o.certified_deliveries && current_routing_order == o.current_routing_order && editors == o.editors && error_details == o.error_details && in_person_signers == o.in_person_signers && intermediaries == o.intermediaries && notaries == o.notaries && notary_witnesses == o.notary_witnesses && participants == o.participants && recipient_count == o.recipient_count && seals == o.seals && signers == o.signers && witnesses == o.witnesses end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/docusign_esign/models/recipients.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_eSign.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/docusign_esign/models/recipients.rb', line 346 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/docusign_esign/models/recipients.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/docusign_esign/models/recipients.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/docusign_esign/models/recipients.rb', line 252 def hash [agents, , carbon_copies, certified_deliveries, current_routing_order, editors, error_details, in_person_signers, intermediaries, notaries, notary_witnesses, participants, recipient_count, seals, signers, witnesses].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
210 211 212 213 |
# File 'lib/docusign_esign/models/recipients.rb', line 210 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/docusign_esign/models/recipients.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 |
# File 'lib/docusign_esign/models/recipients.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/docusign_esign/models/recipients.rb', line 320 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 |
# File 'lib/docusign_esign/models/recipients.rb', line 217 def valid? true end |