Class: DocuSign_eSign::UpdateOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_esign/api/envelopes_api.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#advanced_updateObject

When set to true, allows the caller to update recipients, tabs, custom fields, notification, email settings and other envelope attributes.



513
514
515
# File 'lib/docusign_esign/api/envelopes_api.rb', line 513

def advanced_update
  @advanced_update
end

#recycle_on_voidObject

Returns the value of attribute recycle_on_void.



516
517
518
# File 'lib/docusign_esign/api/envelopes_api.rb', line 516

def recycle_on_void
  @recycle_on_void
end

#resend_envelopeObject

When set to true, sends the specified envelope again.



519
520
521
# File 'lib/docusign_esign/api/envelopes_api.rb', line 519

def resend_envelope
  @resend_envelope
end

Class Method Details

.defaultObject



521
522
523
# File 'lib/docusign_esign/api/envelopes_api.rb', line 521

def self.default
  @@default ||= UpdateOptions.new
end