Class: DocuSign_eSign::UpdateRecipientsOptions
- Inherits:
-
Object
- Object
- DocuSign_eSign::UpdateRecipientsOptions
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb,
lib/docusign_esign/api/templates_api.rb
Instance Attribute Summary collapse
-
#combine_same_order_recipients ⇒ Object
Returns the value of attribute combine_same_order_recipients.
-
#offline_signing ⇒ Object
Returns the value of attribute offline_signing.
-
#resend_envelope ⇒ Object
When set to true, resends the envelope if the new recipient’s routing order is before or the same as the envelope’s next recipient.
Class Method Summary collapse
Instance Attribute Details
#combine_same_order_recipients ⇒ Object
Returns the value of attribute combine_same_order_recipients.
546 547 548 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 546 def combine_same_order_recipients @combine_same_order_recipients end |
#offline_signing ⇒ Object
Returns the value of attribute offline_signing.
549 550 551 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 549 def offline_signing @offline_signing end |
#resend_envelope ⇒ Object
When set to true, resends the envelope if the new recipient’s routing order is before or the same as the envelope’s next recipient.
552 553 554 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 552 def resend_envelope @resend_envelope end |
Class Method Details
.default ⇒ Object
554 555 556 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 554 def self.default @@default ||= UpdateRecipientsOptions.new end |