Method: DocuSign_eSign::EnvelopesApi#create_envelope_recipient_shared_view_with_http_info
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb
#create_envelope_recipient_shared_view_with_http_info(account_id, envelope_id, recipient_view_request) ⇒ Array<(ViewUrl, Fixnum, Hash)>
Provides a URL to start a shared recipient view of the Envelope UI Returns a URL that enables you to embed the DocuSign UI recipient view of a [shared envelope](support.docusign.com/en/guides/ndse-admin-guide-share-envelopes) in your applications. This is the view that a user sees of an envelope that a recipient on the same account has shared with them. Due to screen space issues, do not use an `<iframe>` for embedded operations on mobile devices. For iOS devices, DocuSign recommends using a WebView. ### Revoking the URL You can revoke this URL by making a DELETE HTTP request to the URL with no request body. ### Related topics - [Embedded signing and sending](/docs/esign-rest-api/esign101/concepts/embedding/) - [How to send an envelope via your app](/docs/esign-rest-api/how-to/embedded-sending/) - [How to embed the DocuSign UI in your app](/docs/esign-rest-api/how-to/embed-ui/)
1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 1305 def create_envelope_recipient_shared_view_with_http_info(account_id, envelope_id, recipient_view_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EnvelopesApi.create_envelope_recipient_shared_view ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling EnvelopesApi.create_envelope_recipient_shared_view" if account_id.nil? # verify the required parameter 'envelope_id' is set fail ArgumentError, "Missing the required parameter 'envelope_id' when calling EnvelopesApi.create_envelope_recipient_shared_view" if envelope_id.nil? # resource path local_var_path = "/v2.1/accounts/{accountId}/envelopes/{envelopeId}/views/shared".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'envelopeId' + '}', envelope_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(recipient_view_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ViewUrl') if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvelopesApi#create_envelope_recipient_shared_view\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |