Class: DocuSign_eSign::DocGenFormField
- Inherits:
-
Object
- Object
- DocuSign_eSign::DocGenFormField
- Defined in:
- lib/docusign_esign/models/doc_gen_form_field.rb
Instance Attribute Summary collapse
-
#connected_object_details ⇒ Object
Returns the value of attribute connected_object_details.
-
#default_value ⇒ Object
Returns the value of attribute default_value.
-
#description ⇒ Object
Returns the value of attribute description.
-
#format ⇒ Object
Returns the value of attribute format.
-
#fully_qualified_path ⇒ Object
Returns the value of attribute fully_qualified_path.
-
#hidden ⇒ Object
Returns the value of attribute hidden.
-
#label ⇒ Object
Returns the value of attribute label.
-
#name ⇒ Object
Returns the value of attribute name.
-
#options ⇒ Object
Returns the value of attribute options.
-
#order ⇒ Object
Returns the value of attribute order.
-
#predefined_validation ⇒ Object
Returns the value of attribute predefined_validation.
-
#read_only ⇒ Object
Returns the value of attribute read_only.
-
#required ⇒ Object
When set to true, the signer is required to fill out this tab.
-
#row_values ⇒ Object
Returns the value of attribute row_values.
-
#type ⇒ Object
Returns the value of attribute type.
-
#validation ⇒ Object
Returns the value of attribute validation.
-
#value ⇒ Object
Specifies the value of the tab.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DocGenFormField
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DocGenFormField
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'connectedObjectDetails') self.connected_object_details = attributes[:'connectedObjectDetails'] end if attributes.has_key?(:'defaultValue') self.default_value = attributes[:'defaultValue'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'format') self.format = attributes[:'format'] end if attributes.has_key?(:'fullyQualifiedPath') self.fully_qualified_path = attributes[:'fullyQualifiedPath'] end if attributes.has_key?(:'hidden') self.hidden = attributes[:'hidden'] end if attributes.has_key?(:'label') self.label = attributes[:'label'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end end if attributes.has_key?(:'order') self.order = attributes[:'order'] end if attributes.has_key?(:'predefinedValidation') self.predefined_validation = attributes[:'predefinedValidation'] end if attributes.has_key?(:'readOnly') self.read_only = attributes[:'readOnly'] end if attributes.has_key?(:'required') self.required = attributes[:'required'] end if attributes.has_key?(:'rowValues') if (value = attributes[:'rowValues']).is_a?(Array) self.row_values = value end end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'validation') self.validation = attributes[:'validation'] end if attributes.has_key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#connected_object_details ⇒ Object
Returns the value of attribute connected_object_details.
17 18 19 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 17 def connected_object_details @connected_object_details end |
#default_value ⇒ Object
Returns the value of attribute default_value.
20 21 22 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 20 def default_value @default_value end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 23 def description @description end |
#format ⇒ Object
Returns the value of attribute format.
26 27 28 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 26 def format @format end |
#fully_qualified_path ⇒ Object
Returns the value of attribute fully_qualified_path.
29 30 31 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 29 def fully_qualified_path @fully_qualified_path end |
#hidden ⇒ Object
Returns the value of attribute hidden.
32 33 34 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 32 def hidden @hidden end |
#label ⇒ Object
Returns the value of attribute label.
35 36 37 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 35 def label @label end |
#name ⇒ Object
Returns the value of attribute name.
38 39 40 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 38 def name @name end |
#options ⇒ Object
Returns the value of attribute options.
41 42 43 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 41 def @options end |
#order ⇒ Object
Returns the value of attribute order.
44 45 46 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 44 def order @order end |
#predefined_validation ⇒ Object
Returns the value of attribute predefined_validation.
47 48 49 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 47 def predefined_validation @predefined_validation end |
#read_only ⇒ Object
Returns the value of attribute read_only.
50 51 52 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 50 def read_only @read_only end |
#required ⇒ Object
When set to true, the signer is required to fill out this tab
53 54 55 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 53 def required @required end |
#row_values ⇒ Object
Returns the value of attribute row_values.
56 57 58 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 56 def row_values @row_values end |
#type ⇒ Object
Returns the value of attribute type.
59 60 61 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 59 def type @type end |
#validation ⇒ Object
Returns the value of attribute validation.
62 63 64 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 62 def validation @validation end |
#value ⇒ Object
Specifies the value of the tab.
65 66 67 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 65 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 68 def self.attribute_map { :'connected_object_details' => :'connectedObjectDetails', :'default_value' => :'defaultValue', :'description' => :'description', :'format' => :'format', :'fully_qualified_path' => :'fullyQualifiedPath', :'hidden' => :'hidden', :'label' => :'label', :'name' => :'name', :'options' => :'options', :'order' => :'order', :'predefined_validation' => :'predefinedValidation', :'read_only' => :'readOnly', :'required' => :'required', :'row_values' => :'rowValues', :'type' => :'type', :'validation' => :'validation', :'value' => :'value' } end |
.swagger_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 91 def self.swagger_types { :'connected_object_details' => :'ConnectedObjectDetails', :'default_value' => :'String', :'description' => :'String', :'format' => :'DocGenFormat', :'fully_qualified_path' => :'String', :'hidden' => :'String', :'label' => :'String', :'name' => :'String', :'options' => :'Array<DocGenFormFieldOption>', :'order' => :'String', :'predefined_validation' => :'String', :'read_only' => :'String', :'required' => :'String', :'row_values' => :'Array<DocGenFormFieldRowValue>', :'type' => :'String', :'validation' => :'DocGenFormFieldValidation', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 209 def ==(o) return true if self.equal?(o) self.class == o.class && connected_object_details == o.connected_object_details && default_value == o.default_value && description == o.description && format == o.format && fully_qualified_path == o.fully_qualified_path && hidden == o.hidden && label == o.label && name == o.name && == o. && order == o.order && predefined_validation == o.predefined_validation && read_only == o.read_only && required == o.required && row_values == o.row_values && type == o.type && validation == o.validation && value == o.value end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 267 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_eSign.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 333 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 246 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 239 def hash [connected_object_details, default_value, description, format, fully_qualified_path, hidden, label, name, , order, predefined_validation, read_only, required, row_values, type, validation, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 196 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
313 314 315 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 313 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
307 308 309 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 307 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 |
# File 'lib/docusign_esign/models/doc_gen_form_field.rb', line 203 def valid? true end |