Class: DocuSign_eSign::ListStatusChangesOptions
- Inherits:
-
Object
- Object
- DocuSign_eSign::ListStatusChangesOptions
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb
Instance Attribute Summary collapse
-
#ac_status ⇒ Object
Specifies the Authoritative Copy Status for the envelopes.
-
#block ⇒ Object
Returns the value of attribute block.
-
#cdse_mode ⇒ Object
Returns the value of attribute cdse_mode.
-
#continuation_token ⇒ Object
Returns the value of attribute continuation_token.
-
#count ⇒ Object
Returns the value of attribute count.
-
#custom_field ⇒ Object
This specifies the envelope custom field name and value searched for in the envelope information.
-
#email ⇒ Object
Returns the value of attribute email.
-
#envelope_ids ⇒ Object
Returns the value of attribute envelope_ids.
-
#exclude ⇒ Object
Returns the value of attribute exclude.
-
#folder_ids ⇒ Object
Returns the value of attribute folder_ids.
-
#folder_types ⇒ Object
Returns the value of attribute folder_types.
-
#from_date ⇒ Object
The date/time setting that specifies the date/time when the request begins checking for status changes for envelopes in the account.
-
#from_to_status ⇒ Object
This is the status type checked for in the ‘from_date`/`to_date` period.
-
#include ⇒ Object
Returns the value of attribute include.
-
#include_purge_information ⇒ Object
Returns the value of attribute include_purge_information.
-
#intersecting_folder_ids ⇒ Object
Returns the value of attribute intersecting_folder_ids.
-
#last_queried_date ⇒ Object
Returns the value of attribute last_queried_date.
-
#order ⇒ Object
Returns the value of attribute order.
-
#order_by ⇒ Object
Returns the value of attribute order_by.
-
#powerformids ⇒ Object
Returns the value of attribute powerformids.
-
#query_budget ⇒ Object
Returns the value of attribute query_budget.
-
#requester_date_format ⇒ Object
Returns the value of attribute requester_date_format.
-
#search_mode ⇒ Object
Returns the value of attribute search_mode.
-
#search_text ⇒ Object
Returns the value of attribute search_text.
-
#start_position ⇒ Object
Returns the value of attribute start_position.
-
#status ⇒ Object
The list of current statuses to include in the response.
-
#to_date ⇒ Object
Optional date/time setting that specifies the date/time when the request stops for status changes for envelopes in the account.
-
#transaction_ids ⇒ Object
If included in the query string, this is a comma separated list of envelope ‘transactionId`s.
-
#user_filter ⇒ Object
Returns the value of attribute user_filter.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#user_name ⇒ Object
Returns the value of attribute user_name.
Class Method Summary collapse
Instance Attribute Details
#ac_status ⇒ Object
Specifies the Authoritative Copy Status for the envelopes. The possible values are: Unknown, Original, Transferred, AuthoritativeCopy, AuthoritativeCopyExportPending, AuthoritativeCopyExported, DepositPending, Deposited, DepositedEO, or DepositFailed.
384 385 386 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 384 def ac_status @ac_status end |
#block ⇒ Object
Returns the value of attribute block.
387 388 389 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 387 def block @block end |
#cdse_mode ⇒ Object
Returns the value of attribute cdse_mode.
390 391 392 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 390 def cdse_mode @cdse_mode end |
#continuation_token ⇒ Object
Returns the value of attribute continuation_token.
393 394 395 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 393 def continuation_token @continuation_token end |
#count ⇒ Object
Returns the value of attribute count.
396 397 398 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 396 def count @count end |
#custom_field ⇒ Object
This specifies the envelope custom field name and value searched for in the envelope information. The value portion of the query can use partial strings by adding ‘%’ (percent sign) around the custom field query value. Example 1: If you have an envelope custom field called "Region" and you want to search for all envelopes where the value is "West" you would use the query: ‘?custom_field=Region=West`. Example 2: To search for envelopes where the `ApplicationID` custom field has the value or partial value of "DocuSign" in field, the query would be: `?custom_field=ApplicationId=%DocuSign%` This would find envelopes where the custom field value is "DocuSign for Salesforce" or "DocuSign envelope."
399 400 401 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 399 def custom_field @custom_field end |
#email ⇒ Object
Returns the value of attribute email.
402 403 404 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 402 def email @email end |
#envelope_ids ⇒ Object
Returns the value of attribute envelope_ids.
405 406 407 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 405 def envelope_ids @envelope_ids end |
#exclude ⇒ Object
Returns the value of attribute exclude.
408 409 410 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 408 def exclude @exclude end |
#folder_ids ⇒ Object
Returns the value of attribute folder_ids.
411 412 413 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 411 def folder_ids @folder_ids end |
#folder_types ⇒ Object
Returns the value of attribute folder_types.
414 415 416 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 414 def folder_types @folder_types end |
#from_date ⇒ Object
The date/time setting that specifies the date/time when the request begins checking for status changes for envelopes in the account. This is required unless ‘envelopeId’s are used.
417 418 419 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 417 def from_date @from_date end |
#from_to_status ⇒ Object
This is the status type checked for in the ‘from_date`/`to_date` period. If `changed` is specified, then envelopes that changed status during the period are found. If for example, `created` is specified, then envelopes created during the period are found. Default is `changed`. Possible values are: Voided, Changed, Created, Deleted, Sent, Delivered, Signed, Completed, Declined, TimedOut and Processing.
420 421 422 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 420 def from_to_status @from_to_status end |
#include ⇒ Object
Returns the value of attribute include.
423 424 425 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 423 def include @include end |
#include_purge_information ⇒ Object
Returns the value of attribute include_purge_information.
426 427 428 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 426 def include_purge_information @include_purge_information end |
#intersecting_folder_ids ⇒ Object
Returns the value of attribute intersecting_folder_ids.
429 430 431 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 429 def intersecting_folder_ids @intersecting_folder_ids end |
#last_queried_date ⇒ Object
Returns the value of attribute last_queried_date.
432 433 434 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 432 def last_queried_date @last_queried_date end |
#order ⇒ Object
Returns the value of attribute order.
435 436 437 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 435 def order @order end |
#order_by ⇒ Object
Returns the value of attribute order_by.
438 439 440 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 438 def order_by @order_by end |
#powerformids ⇒ Object
Returns the value of attribute powerformids.
441 442 443 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 441 def powerformids @powerformids end |
#query_budget ⇒ Object
Returns the value of attribute query_budget.
444 445 446 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 444 def query_budget @query_budget end |
#requester_date_format ⇒ Object
Returns the value of attribute requester_date_format.
447 448 449 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 447 def requester_date_format @requester_date_format end |
#search_mode ⇒ Object
Returns the value of attribute search_mode.
450 451 452 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 450 def search_mode @search_mode end |
#search_text ⇒ Object
Returns the value of attribute search_text.
453 454 455 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 453 def search_text @search_text end |
#start_position ⇒ Object
Returns the value of attribute start_position.
456 457 458 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 456 def start_position @start_position end |
#status ⇒ Object
The list of current statuses to include in the response. By default, all envelopes found are returned. If values are specified, then of the envelopes found, only those with the current status specified are returned in the results. Possible values are: Voided, Created, Deleted, Sent, Delivered, Signed, Completed, Declined, TimedOut and Processing.
459 460 461 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 459 def status @status end |
#to_date ⇒ Object
Optional date/time setting that specifies the date/time when the request stops for status changes for envelopes in the account. If no entry, the system uses the time of the call as the ‘to_date`.
462 463 464 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 462 def to_date @to_date end |
#transaction_ids ⇒ Object
If included in the query string, this is a comma separated list of envelope ‘transactionId`s. If included in the `request_body`, this is a list of envelope `transactionId`s. ###### Note: `transactionId`s are only valid in the DocuSign system for seven days.
465 466 467 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 465 def transaction_ids @transaction_ids end |
#user_filter ⇒ Object
Returns the value of attribute user_filter.
468 469 470 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 468 def user_filter @user_filter end |
#user_id ⇒ Object
Returns the value of attribute user_id.
471 472 473 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 471 def user_id @user_id end |
#user_name ⇒ Object
Returns the value of attribute user_name.
474 475 476 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 474 def user_name @user_name end |
Class Method Details
.default ⇒ Object
476 477 478 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 476 def self.default @@default ||= ListStatusChangesOptions.new end |