Class: DocuSign_eSign::UpdateRecipientsOptions
- Inherits:
-
Object
- Object
- DocuSign_eSign::UpdateRecipientsOptions
- Defined in:
- lib/docusign_esign/api/envelopes_api.rb,
lib/docusign_esign/api/templates_api.rb
Instance Attribute Summary collapse
-
#combine_same_order_recipients ⇒ Object
Returns the value of attribute combine_same_order_recipients.
-
#offline_signing ⇒ Object
Returns the value of attribute offline_signing.
-
#resend_envelope ⇒ Object
When set to true, resends the envelope if the new recipient’s routing order is before or the same as the envelope’s next recipient.
Class Method Summary collapse
Instance Attribute Details
#combine_same_order_recipients ⇒ Object
Returns the value of attribute combine_same_order_recipients.
489 490 491 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 489 def combine_same_order_recipients @combine_same_order_recipients end |
#offline_signing ⇒ Object
Returns the value of attribute offline_signing.
492 493 494 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 492 def offline_signing @offline_signing end |
#resend_envelope ⇒ Object
When set to true, resends the envelope if the new recipient’s routing order is before or the same as the envelope’s next recipient.
495 496 497 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 495 def resend_envelope @resend_envelope end |
Class Method Details
.default ⇒ Object
497 498 499 |
# File 'lib/docusign_esign/api/envelopes_api.rb', line 497 def self.default @@default ||= UpdateRecipientsOptions.new end |